@@ -17,8 +17,9 @@ dtype = np.float64
 typesize = dtype.itemsize
 
 # Create a NDArray from a NumPy array
-array = np.random.normal(0, 1, np.prod(shape)).reshape(shape)
+random = np.random.default_rng()
+array = random.normal(0, 1, np.prod(shape)).reshape(shape)
 # Use NDMEAN filter
-cparams = {"filters": [blosc2.Filter.NDMEAN], "filters_meta": [4]}
+cparams = blosc2.CParams(filters=[blosc2.Filter.NDMEAN], filters_meta=[4])
 a = blosc2.asarray(array, chunks=chunks, cparams=cparams)
 print("compression ratio:", a.schunk.cratio)
