@@ -7,12 +7,12 @@
 #######################################################################
 
 
+# A simple example using the pack and unpack functions
 import numpy as np
 
-# A simple example using the pack and unpack functions
 import blosc2
 
 a = np.array(["å", "ç", "ø"])
 parray = blosc2.pack(a, 9)
 a2 = blosc2.unpack(parray)
-assert np.alltrue(a == a2)
+assert np.all(a == a2)
