@@ -14,17 +14,19 @@ nchunks = 10
 input_dtype = np.dtype(np.int64)
 
 # Set the compression and decompression parameters
-cparams = {"codec": blosc2.Codec.LZ4, "typesize": input_dtype.itemsize}
-dparams = {"nthreads": 1}
+cparams = blosc2.CParams(codec=blosc2.Codec.LZ4, typesize=input_dtype.itemsize)
+dparams = blosc2.DParams(nthreads=1)
 contiguous = False
 urlpath = None
-storage = {"contiguous": contiguous, "urlpath": urlpath, "cparams": cparams, "dparams": dparams}
+storage = blosc2.Storage(contiguous=contiguous, urlpath=urlpath, mode="a")
 # Remove previous SChunk
 blosc2.remove_urlpath(urlpath)
 # Create and set data
 chunkshape = 20_000
 data = np.zeros(chunkshape * nchunks, dtype=input_dtype)
-schunk = blosc2.SChunk(chunksize=chunkshape * input_dtype.itemsize, data=data, **storage)
+schunk = blosc2.SChunk(
+    chunksize=chunkshape * input_dtype.itemsize, data=data, cparams=cparams, dparams=dparams, storage=storage
+)
 
 out1 = np.empty(chunkshape * nchunks, dtype=input_dtype)
 schunk.get_slice(0, chunkshape * nchunks, out=out1)
