@@ -13,7 +13,7 @@ import blosc2
 
 
 @pytest.mark.parametrize(
-    "shape, chunks, blocks, dtype, cparams, urlpath, contiguous",
+    ("shape", "chunks", "blocks", "dtype", "cparams", "urlpath", "contiguous"),
     [
         (
             (100, 1230),
@@ -65,16 +65,15 @@ import blosc2
 def test_empty(shape, chunks, blocks, dtype, cparams, urlpath, contiguous):
     blosc2.remove_urlpath(urlpath)
     filters = cparams["filters"]
-    cparams["filters_meta"] = [0] * len(filters)
+    storage = blosc2.Storage(urlpath=urlpath, contiguous=contiguous)
     a = blosc2.empty(
         shape,
         chunks=chunks,
         blocks=blocks,
         dtype=dtype,
-        cparams=cparams,
+        storage=storage,
+        cparams=blosc2.CParams(**cparams),
         dparams={"nthreads": 2},
-        urlpath=urlpath,
-        contiguous=contiguous,
     )
 
     dtype = np.dtype(dtype)
@@ -83,16 +82,16 @@ def test_empty(shape, chunks, blocks, dtype, cparams, urlpath, contiguous):
     assert a.blocks == blocks
     assert a.dtype == dtype
     assert a.schunk.typesize == dtype.itemsize
-    assert a.schunk.cparams["codec"] == cparams["codec"]
-    assert a.schunk.cparams["clevel"] == cparams["clevel"]
-    assert a.schunk.cparams["filters"][: len(filters)] == filters
-    assert a.schunk.dparams["nthreads"] == 2
+    assert a.schunk.cparams.codec == cparams["codec"]
+    assert a.schunk.cparams.clevel == cparams["clevel"]
+    assert a.schunk.cparams.filters[: len(filters)] == filters
+    assert a.schunk.dparams.nthreads == 2
 
     blosc2.remove_urlpath(urlpath)
 
 
 @pytest.mark.parametrize(
-    "shape, dtype",
+    ("shape", "dtype"),
     [
         (100, np.uint8),
         ((100, 1230), np.uint8),
@@ -107,19 +106,37 @@ def test_empty_minimal(shape, dtype):
     assert shape in (a.shape, a.shape[0])
     assert a.chunks is not None
     assert a.blocks is not None
-    assert all(c >= b for c, b in zip(a.chunks, a.blocks))
+    assert all(c >= b for c, b in zip(a.chunks, a.blocks, strict=False))
     assert a.dtype == dtype
     assert a.schunk.typesize == dtype.itemsize
 
 
 @pytest.mark.parametrize(
-    "shape, cparams",
+    ("shape", "cparams"),
     [
-        (100, dict(chunks=(10,))),
-        ((100,), dict(blocks=(10,))),
-        ((100,), dict(chunks=(10,), blocks=(10,))),
+        (100, {"chunks": (10,)}),
+        ((100,), {"blocks": (10,)}),
+        ((100,), {"chunks": (10,), "blocks": (10,)}),
     ],
 )
 def test_cparams_chunks_blocks(shape, cparams):
     with pytest.raises(ValueError):
         blosc2.empty(shape, cparams=cparams)
+
+
+def test_zero_in_blockshape():
+    # Check for #165
+    with pytest.raises(ValueError):
+        blosc2.empty(shape=(1200,), chunks=(100,), blocks=(0,))
+
+
+def test_large_itemsize():
+    # Check for #364
+    a = blosc2.empty(shape=10, dtype=f"S{100_000_000}")
+    assert a.blocks == (1,)
+
+
+def test_toolarge_itemsize():
+    # blocksize cannot be larger that MAX_BLOCKSIZE
+    with pytest.raises(ValueError):
+        a = blosc2.empty(shape=10, dtype=f"S{blosc2.MAX_BLOCKSIZE}", blocks=(2,))
