@@ -10,13 +10,14 @@ import pathlib
 
 import numpy as np
 import pytest
+import torch
 
 import blosc2
 from blosc2.lazyexpr import ne_evaluate
 from blosc2.ndarray import get_chunks_idx, npvecdot
 
-NITEMS_SMALL = 1_000
-NITEMS = 10_000
+NITEMS_SMALL = 100
+NITEMS = 1000
 
 
 @pytest.fixture(params=[np.float32, np.float64])
@@ -24,7 +25,7 @@ def dtype_fixture(request):
     return request.param
 
 
-@pytest.fixture(params=[(NITEMS_SMALL,), (NITEMS,), (NITEMS // 100, 100)])
+@pytest.fixture(params=[(NITEMS_SMALL,), (NITEMS,), (NITEMS // 10, 100)])
 def shape_fixture(request):
     return request.param
 
@@ -35,7 +36,7 @@ def shape_fixture(request):
         (True, True),
         (True, False),
         pytest.param((False, True), marks=pytest.mark.heavy),
-        (False, False),
+        pytest.param((False, False), marks=pytest.mark.heavy),
     ]
 )
 def chunks_blocks_fixture(request):
@@ -358,12 +359,7 @@ def test_functions(function, dtype_fixture, shape_fixture):
 )
 @pytest.mark.parametrize(
     ("value1", "value2"),
-    [
-        ("NDArray", "scalar"),
-        ("NDArray", "NDArray"),
-        ("scalar", "NDArray"),
-        # ("scalar", "scalar") # Not supported by LazyExpr
-    ],
+    [("NDArray", "scalar"), ("NDArray", "NDArray"), ("scalar", "NDArray"), ("scalar", "scalar")],
 )
 def test_arctan2_pow(urlpath, shape_fixture, dtype_fixture, function, value1, value2):
     nelems = np.prod(shape_fixture)
@@ -405,7 +401,7 @@ def test_arctan2_pow(urlpath, shape_fixture, dtype_fixture, function, value1, va
             else:
                 expr_string = f"{function}(na1, value2)"
                 res_numexpr = ne_evaluate(expr_string)
-    else:  # ("scalar", "NDArray")
+    elif value2 == "NDArray":  # ("scalar", "NDArray")
         value1 = 12
         na2 = np.linspace(0, 10, nelems, dtype=dtype_fixture).reshape(shape_fixture)
         a2 = blosc2.asarray(na2, urlpath=urlpath2, mode="w")
@@ -421,9 +417,21 @@ def test_arctan2_pow(urlpath, shape_fixture, dtype_fixture, function, value1, va
         else:
             expr_string = f"{function}(value1, na2)"
             res_numexpr = ne_evaluate(expr_string)
+    else:  # ("scalar", "scalar")
+        value1 = 12
+        value2 = 3
+        # Construct the lazy expression based on the function name
+        expr = blosc2.LazyExpr(new_op=(value1, function, value2))
+        res_lazyexpr = expr.compute()
+        # Evaluate using NumExpr
+        if function == "**":
+            res_numexpr = ne_evaluate("value1**value2")
+        else:
+            expr_string = f"{function}(value1, value2)"
+            res_numexpr = ne_evaluate(expr_string)
     # Compare the results
     tol = 1e-15 if dtype_fixture == "float64" else 1e-6
-    np.testing.assert_allclose(res_lazyexpr[:], res_numexpr, atol=tol, rtol=tol)
+    np.testing.assert_allclose(res_lazyexpr[()], res_numexpr, atol=tol, rtol=tol)
 
     for path in [urlpath1, urlpath2, urlpath_save]:
         blosc2.remove_urlpath(path)
@@ -1195,7 +1203,7 @@ def test_fill_disk_operands(chunks, blocks, disk, fill_value):
         b = blosc2.open("b.b2nd")
         c = blosc2.open("c.b2nd")
 
-    expr = ((a**3 + blosc2.sin(c * 2)) < b) & (c > 0)
+    expr = ((a**3 + blosc2.sin(c * 2)) < b) & ~(c > 0)
 
     out = expr.compute()
     assert out.shape == (N, N)
@@ -1335,6 +1343,33 @@ def test_sort():
         expr.sort().compute()
 
 
+def test_listargs():
+    # lazyexpr tries to convert [] to slice, but could
+    # have problems for arguments which are lists
+    shape = (20,)
+    na = np.arange(shape[0])
+    a = blosc2.asarray(na)
+    b = blosc2.asarray(na)
+    expr = blosc2.lazyexpr("stack([a, b])")
+    np.testing.assert_array_equal(expr[:], np.stack([a[:], b[:]]))
+
+
+def test_str_constructors():
+    shape = (1000, 1)
+    chunks = (100, 1)
+    a = blosc2.lazyexpr(f"linspace(0, 100, {np.prod(shape)}, shape={shape}, chunks={chunks})")
+    assert a.chunks == chunks
+    b = blosc2.lazyexpr("a.T")  # this fails unless chunkshape is assigned to a on creation
+
+    b = blosc2.ones((1000, 10))
+    a = blosc2.lazyexpr(f"b + linspace(0, 100, {np.prod(shape)}, shape={shape}, chunks={chunks})")
+    assert a.shape == np.broadcast_shapes(shape, b.shape)
+
+    # failed before dtype handling improved
+    x = blosc2.lazyexpr("linspace(-1, 1, 10, shape=(1, 10))")
+    lexpr = blosc2.sin(blosc2.sqrt(x**2))
+
+
 @pytest.mark.parametrize(
     "obj",
     [
@@ -1389,14 +1424,14 @@ def test_missing_operator():
     a = blosc2.arange(10, urlpath="a.b2nd", mode="w")
     b = blosc2.arange(10, urlpath="b.b2nd", mode="w")
     expr = blosc2.lazyexpr("a + b")
-    c = expr.save("expr.b2nd", mode="w")
+    expr.save("expr.b2nd", mode="w")
     # Remove the file for operand b
     blosc2.remove_urlpath("b.b2nd")
     # Re-open the lazy expression
     with pytest.raises(blosc2.exceptions.MissingOperands) as excinfo:
         blosc2.open("expr.b2nd")
 
-    # Check that some operand is missing"
+    # Check that some operand is missing
     assert "a" not in excinfo.value.missing_ops
     assert excinfo.value.missing_ops["b"] == pathlib.Path("b.b2nd")
     assert excinfo.value.expr == "a + b"
@@ -1454,6 +1489,13 @@ def test_chain_expressions():
     assert lexpr1.expression == lexpr3.expression
     assert lexpr1.operands == lexpr3.operands
 
+    # chain constructors
+    expr1 = "linspace(0, 10, 100)"
+    lexpr1 = blosc2.lazyexpr(expr1)
+    lexpr1 *= 2
+    assert lexpr1.expression == "((linspace(0, 10, 100)) * 2)"
+    assert lexpr1.shape == (100,)
+
 
 # Test the chaining of multiple persistent lazy expressions
 def test_chain_persistentexpressions():
@@ -1510,6 +1552,11 @@ def test_scalar_dtypes(values):
     dtype2 = (avalue1 * avalue2).dtype
     assert dtype1 == dtype2, f"Expected {dtype1} but got {dtype2}"
 
+    # test scalars
+    value = value1 if np.isscalar(value1) else value2
+    assert blosc2.sin(value)[()] == np.sin(value)
+    assert (value + blosc2.sin(value))[()] == value + np.sin(value)
+
 
 def test_to_cframe():
     N = 1_000
@@ -1697,13 +1744,12 @@ def test_lazylinalg():
     np.testing.assert_array_almost_equal(out[()], npres)
 
     # --- squeeze ---
-    out = blosc2.lazyexpr("squeeze(D)")
-    npres = np.squeeze(npD)
+    out = blosc2.lazyexpr("squeeze(D, axis=-1)")
+    npres = np.squeeze(npD, -1)
     assert out.shape == npres.shape
     np.testing.assert_array_almost_equal(out[()], npres)
-
-    out = blosc2.lazyexpr("D.squeeze()")
-    npres = np.squeeze(npD)
+    out = blosc2.lazyexpr("D.squeeze(axis=-1)")
+    npres = np.squeeze(npD, -1)
     assert out.shape == npres.shape
     np.testing.assert_array_almost_equal(out[()], npres)
 
@@ -1712,12 +1758,22 @@ def test_lazylinalg():
     npres = np.stack((npx, npy), axis=0)
     assert out.shape == npres.shape
     np.testing.assert_array_almost_equal(out[()], npres)
+    # --- stack ---
+    # repeat with list arg instead of tuple
+    out = blosc2.lazyexpr("stack([x, y], axis=0)")
+    npres = np.stack((npx, npy), axis=0)
+    assert out.shape == npres.shape
+    np.testing.assert_array_almost_equal(out[()], npres)
 
     # --- tensordot ---
-    out = blosc2.lazyexpr("tensordot(A, B, axes=1)")
+    out = blosc2.lazyexpr("tensordot(A, B, axes=1)")  # test with int axes
     npres = np.tensordot(npA, npB, axes=1)
     assert out.shape == npres.shape
     np.testing.assert_array_almost_equal(out[()], npres)
+    out = blosc2.lazyexpr("tensordot(A, B, axes=((1,) , (0,)))")  # test with tuple axes
+    npres = np.tensordot(npA, npB, axes=((1,), (0,)))
+    assert out.shape == npres.shape
+    np.testing.assert_array_almost_equal(out[()], npres)
 
     # --- vecdot ---
     out = blosc2.lazyexpr("vecdot(x, y)")
@@ -1768,3 +1824,55 @@ def test_lazyexpr_2args():
     newexpr = blosc2.hypot(lexpr, 3)
     assert newexpr.expression == "hypot((sin(o0)), 3)"
     assert newexpr.operands["o0"] is a
+
+
+@pytest.mark.parametrize(
+    "xp",
+    [torch, np],
+)
+@pytest.mark.parametrize(
+    "dtype",
+    ["bool", "int32", "int64", "float32", "float64", "complex128"],
+)
+def test_simpleproxy(xp, dtype):
+    try:
+        dtype_ = getattr(xp, dtype) if hasattr(xp, dtype) else np.dtype(dtype)
+    except FutureWarning:
+        dtype_ = np.dtype(dtype)
+    if dtype == "bool":
+        blosc_matrix = blosc2.asarray([True, False, False], dtype=np.dtype(dtype), chunks=(2,))
+        foreign_matrix = xp.zeros((3,), dtype=dtype_)
+        # Create a lazy expression object
+        lexpr = blosc2.lazyexpr(
+            "(b & a) | (~b)", operands={"a": blosc_matrix, "b": foreign_matrix}
+        )  # this does not
+        # Compare with numpy computation result
+        npb = np.asarray(foreign_matrix)
+        npa = blosc_matrix[()]
+        res = (npb & npa) | np.logical_not(npb)
+    else:
+        N = 5
+        shape_a = (N, N, N)
+        blosc_matrix = blosc2.full(shape=shape_a, fill_value=3, dtype=np.dtype(dtype), chunks=(N // 2,) * 3)
+        foreign_matrix = xp.ones(shape_a, dtype=dtype_)
+        if dtype == "complex128":
+            foreign_matrix += 0.5j
+            blosc_matrix = blosc2.full(
+                shape=shape_a, fill_value=3 + 2j, dtype=np.dtype(dtype), chunks=(N // 3,) * 3
+            )
+
+        # Create a lazy expression object
+        lexpr = blosc2.lazyexpr(
+            "b + sin(a) + sum(b) - tensordot(a, b, axes=1)",
+            operands={"a": blosc_matrix, "b": foreign_matrix},
+        )  # this does not
+        # Compare with numpy computation result
+        npb = np.asarray(foreign_matrix)
+        npa = blosc_matrix[()]
+        res = npb + np.sin(npa) + np.sum(npb) - np.tensordot(npa, npb, axes=1)
+
+    # Test object metadata and result
+    assert isinstance(lexpr, blosc2.LazyExpr)
+    assert lexpr.dtype == res.dtype
+    assert lexpr.shape == res.shape
+    np.testing.assert_array_equal(lexpr[()], res)
