@@ -1,9 +1,12 @@
+import inspect
 from itertools import permutations
 
 import numpy as np
 import pytest
+import torch
 
 import blosc2
+from blosc2.lazyexpr import linalg_funcs
 from blosc2.ndarray import npvecdot
 
 
@@ -13,7 +16,7 @@ from blosc2.ndarray import npvecdot
         ((12, 10), (7, 5), (3, 3)),
         ((10,), (9,), (7,)),
         ((0,), (0,), (0,)),
-        ((40, 10, 10), (2, 3, 4), (1, 2, 2)),
+        ((4, 10, 10), (2, 3, 4), (1, 2, 2)),
     },
 )
 @pytest.mark.parametrize(
@@ -22,9 +25,9 @@ from blosc2.ndarray import npvecdot
         ((10,), (4,), (2,)),
         ((10, 5), (3, 4), (1, 3)),
         ((10, 12), (2, 4), (1, 2)),
-        ((200, 10, 22), (23, 2, 4), (4, 1, 2)),
+        ((3, 10, 3), (2, 2, 4), (1, 1, 2)),
         ((0,), (0,), (0,)),
-        ((20, 40, 10, 10), (5, 2, 3, 4), (2, 1, 2, 2)),
+        ((6, 3, 10, 10), (5, 2, 3, 4), (2, 1, 2, 2)),
     },
 )
 @pytest.mark.parametrize(
@@ -240,6 +243,8 @@ def test_matmul_disk():
             (10, 5),
             ([1], [0]),
         ),
+        # 2Dx2D->axes arg integer
+        ((10, 13), (7, 2), (3, 1), (12, 10), (4, 5), (3, 3), (3, 5), 1),
         # 3Dx3D->contraction along last/first
         (
             (10, 20, 30),
@@ -299,13 +304,13 @@ def test_matmul_disk():
         ),
         # 5Dx5D->no reduce
         (
-            (3, 4, 5, 6, 7),
-            (2, 3, 4, 5, 6),
-            (1, 2, 2, 3, 3),
-            (5, 6, 7, 4, 8),
-            (4, 5, 6, 3, 7),
-            (2, 3, 3, 2, 4),
-            (2, 3, 4, 5, 6, 2, 3, 3, 2, 4),  # output dims = 10
+            (1, 2, 1, 5, 3),
+            (1, 1, 1, 2, 2),
+            (1, 1, 1, 1, 1),
+            (2, 3, 2, 1, 5),
+            (1, 2, 1, 1, 3),
+            (1, 2, 1, 1, 1),
+            (1, 2, 1, 2, 2, 2, 1, 2, 1, 3),  # output dims = 10
             ([], []),
         ),
     ],
@@ -817,3 +822,64 @@ def test_diagonal(shape, chunkshape, offset):
 
     # Assert equality
     np.testing.assert_array_equal(result_np, expected)
+
+
+@pytest.mark.parametrize(
+    "xp",
+    [torch, np],
+)
+@pytest.mark.parametrize(
+    "dtype",
+    ["int32", "int64", "float32", "float64", "complex128"],
+)
+def test_linalgproxy(xp, dtype):
+    dtype_ = getattr(xp, dtype) if hasattr(xp, dtype) else np.dtype(dtype)
+    for name in linalg_funcs:
+        if name == "transpose":
+            continue  # deprecated
+        func = getattr(blosc2, name)
+        N = 10
+        shape_a = (N,)
+        chunks = (N // 3,)
+        if name != "outer":
+            shape_a *= 3
+            chunks *= 3
+        blosc_matrix = blosc2.full(shape=shape_a, fill_value=3, dtype=np.dtype(dtype), chunks=chunks)
+        foreign_matrix = xp.ones(shape_a, dtype=dtype_)
+        if dtype == "complex128":
+            foreign_matrix += 0.5j
+            blosc_matrix = blosc2.full(
+                shape=shape_a, fill_value=3 + 2j, dtype=np.dtype(dtype), chunks=chunks
+            )
+
+        # Check this works
+        argspec = inspect.getfullargspec(func)
+        num_args = len(argspec.args)
+        # handle numpy 1.26
+        if name == "permute_dims":
+            npfunc = blosc2.linalg.nptranspose
+        elif name == "concat" and not hasattr(np, "concat"):
+            npfunc = np.concatenate
+        elif name == "matrix_transpose":
+            npfunc = blosc2.linalg.nptranspose
+        elif name == "vecdot":
+            npfunc = blosc2.linalg.npvecdot
+        else:
+            npfunc = getattr(np, name)
+        if num_args > 2 or name in ("outer", "matmul"):
+            try:
+                lexpr = func(blosc_matrix, foreign_matrix)
+            except NotImplementedError:
+                continue
+            foreign_matrix = np.asarray(foreign_matrix)
+            res = npfunc(blosc_matrix[()], foreign_matrix)
+        else:
+            try:
+                lexpr = func(foreign_matrix)
+            except NotImplementedError:
+                continue
+            except TypeError:
+                continue
+            foreign_matrix = np.asarray(foreign_matrix)
+            res = npfunc(foreign_matrix, 0) if name == "expand_dims" else npfunc(foreign_matrix)
+        np.testing.assert_array_equal(res, lexpr[()])
