@@ -15,21 +15,21 @@ import blosc2
 @pytest.mark.parametrize("mode", ["r", "w", "a"])
 @pytest.mark.parametrize("urlpath", ["test_mode.b2nd"])
 @pytest.mark.parametrize(
-    "shape, fill_value, dtype, cparams, dparams, contiguous",
+    ("shape", "fill_value", "dtype", "cparams", "dparams", "contiguous"),
     [
         (
             (80, 51, 60),
             3.14,
             np.float64,
             {"codec": blosc2.Codec.ZLIB, "clevel": 5, "use_dict": False, "nthreads": 2},
-            {"nthreads": 1},
+            blosc2.DParams(nthreads=1),
             False,
         ),
         (
             (13, 13),
             123456789,
             None,
-            {"codec": blosc2.Codec.LZ4HC, "clevel": 8, "use_dict": False, "nthreads": 2},
+            blosc2.CParams(codec=blosc2.Codec.LZ4HC, clevel=8, use_dict=False, nthreads=2),
             {"nthreads": 2},
             True,
         ),
@@ -45,9 +45,7 @@ def test_mode(shape, fill_value, cparams, dparams, dtype, urlpath, contiguous, m
                 dtype=dtype,
                 cparams=cparams,
                 dparams=dparams,
-                urlpath=urlpath,
-                contiguous=contiguous,
-                mode=mode,
+                storage={"urlpath": urlpath, "contiguous": contiguous, "mode": mode},
             )
     _ = blosc2.full(
         shape,
@@ -55,8 +53,7 @@ def test_mode(shape, fill_value, cparams, dparams, dtype, urlpath, contiguous, m
         dtype=dtype,
         cparams=cparams,
         dparams=dparams,
-        urlpath=urlpath,
-        contiguous=contiguous,
+        storage={"urlpath": urlpath, "contiguous": contiguous},
     )
 
     a = blosc2.open(urlpath, mode=mode)
