@@ -12,39 +12,49 @@ import pytest
 
 import blosc2
 
+random = np.random.default_rng()
+
 
 @pytest.mark.parametrize("gil", [True, False])
 @pytest.mark.parametrize(
-    "obj, cparams, dparams",
+    ("obj", "cparams", "dparams"),
     [
-        (np.random.randint(0, 10, 10), {"codec": blosc2.Codec.LZ4, "clevel": 6}, {}),
+        (random.integers(0, 10, 10), {"cparams": blosc2.CParams(codec=blosc2.Codec.LZ4, clevel=6)}, {}),
         (
             np.arange(10, dtype="float32"),
             # Select an absolute precision of 10 bits in mantissa
             {
-                "filters": [blosc2.Filter.TRUNC_PREC, blosc2.Filter.BITSHUFFLE],
-                "filters_meta": [10, 0],
-                "typesize": 4,
+                "cparams": blosc2.CParams(
+                    filters=[blosc2.Filter.TRUNC_PREC, blosc2.Filter.BITSHUFFLE],
+                    filters_meta=[10, 0],
+                    typesize=4,
+                )
             },
-            {"nthreads": 4},
+            {"dparams": blosc2.DParams(nthreads=4)},
         ),
         (
             np.arange(10, dtype="float32"),
             # Do a reduction of precision of 10 bits in mantissa
             {
-                "filters": [blosc2.Filter.TRUNC_PREC, blosc2.Filter.BITSHUFFLE],
-                "filters_meta": [-10, 0],
-                "typesize": 4,
+                "cparams": {
+                    "filters": [blosc2.Filter.TRUNC_PREC, blosc2.Filter.BITSHUFFLE],
+                    "filters_meta": [-10, 0],
+                    "typesize": 4,
+                },
             },
             {"nthreads": 4},
         ),
         (
-            np.random.randint(0, 1000 + 1, 1000),
-            {"splitmode": blosc2.SplitMode.ALWAYS_SPLIT, "nthreads": 5, "typesize": 4},
+            random.integers(0, 1000, 1000, endpoint=True),
+            {"cparams": blosc2.CParams(splitmode=blosc2.SplitMode.ALWAYS_SPLIT, nthreads=5, typesize=4)},
+            {"dparams": blosc2.DParams()},
+        ),
+        (
+            np.arange(45, dtype=np.float64),
+            {"cparams": blosc2.CParams(codec=blosc2.Codec.LZ4HC, typesize=4)},
             {},
         ),
-        (np.arange(45, dtype=np.float64), {"codec": blosc2.Codec.LZ4HC, "typesize": 4}, {}),
-        (np.arange(50, dtype=np.int64), {"typesize": 4}, blosc2.dparams_dflts),
+        (np.arange(50, dtype=np.int64), {"typesize": 4}, {"dparams": blosc2.dparams_dflts}),
     ],
 )
 def test_compress2_numpy(obj, cparams, dparams, gil):
@@ -70,12 +80,12 @@ def test_compress2_numpy(obj, cparams, dparams, gil):
 
 @pytest.mark.parametrize("gil", [True, False])
 @pytest.mark.parametrize(
-    "obj, cparams, dparams",
+    ("obj", "cparams", "dparams"),
     [
         (
-            np.random.randint(0, 10, 10, dtype=np.int64),
+            random.integers(0, 10, 10, dtype=np.int64),
             {"codec": blosc2.Codec.LZ4, "clevel": 6, "filters_meta": [-50]},
-            {}
+            {},
         ),
         (
             np.arange(10, dtype="int32"),
@@ -96,12 +106,12 @@ def test_compress2_int_trunc(obj, cparams, dparams, gil):
     blosc2.decompress2(c, dst=dest, **dparams)
 
     for i in range(obj.shape[0]):
-        assert (obj[i] - dest[i]) <= (2**((-1)*cparams["filters_meta"][0]))
+        assert (obj[i] - dest[i]) <= (2 ** ((-1) * cparams["filters_meta"][0]))
 
 
 @pytest.mark.parametrize("gil", [True, False])
 @pytest.mark.parametrize(
-    "nbytes, cparams, dparams",
+    ("nbytes", "cparams", "dparams"),
     [
         (7, {"codec": blosc2.Codec.LZ4, "clevel": 6, "typesize": 1}, {}),
         (641091, {"typesize": 1}, {"nthreads": 4}),
@@ -128,7 +138,7 @@ def test_compress2(nbytes, cparams, dparams, gil):
 
 @pytest.mark.parametrize("gil", [True, False])
 @pytest.mark.parametrize(
-    "object, cparams, dparams",
+    ("object", "cparams", "dparams"),
     [(np.arange(0), {"codec": blosc2.Codec.LZ4, "clevel": 6}, {}), (b"", {}, {"nthreads": 3})],
 )
 def test_raise_error(object, cparams, dparams, gil):
